@@ -14,18 +14,19 @@
 #' \describe{
 #'   \item{`box_read_csv()`}{parse a remote CSV file into a `data.frame`. Default
 #'   read-function is [rio::import()] with `format = "csv"`, which uses [data.table::fread()] if available,
-#'   and [utils::read.csv()] if not. Pass the argument `fread = FALSE` to `...`
-#'   to always use [utils::read.csv()].}
+#'   and `utils::read.csv()` if not. Pass the argument `fread = FALSE` to `...`
+#'   to always use `utils::read.csv()`.}
 #'   \item{`box_read_tsv()`}{parse a remote TSV file into a `data.frame`. Default
 #'   read-function is [rio::import()] with `format = "tsv"`, which uses [data.table::fread()] if available,
-#'   and [utils::read.delim()] if not. Pass the argument `fread = FALSE` to `...`
-#'   to always use [utils::read.delim()].}
+#'   and `utils::read.delim()` if not. Pass the argument `fread = FALSE` to `...`
+#'   to always use `utils::read.delim()`.}
 #'   \item{`box_read_json()`}{parse a remote JSON file into a R object. Default
 #'   read-function is [jsonlite::fromJSON()].}
 #'   \item{`box_read_excel()`}{parse a remote Microsoft Excel file into a `data.frame`. Default
 #'   read-function is [rio::import()] with `format = "excel"`, which uses [readxl::read_excel()] by default.
 #'   Pass the argument `readxl = FALSE` to `...` to use [openxlsx::read.xlsx()] instead.}
-#'   }
+#'   \item{`box_read_rds()`}{parse an RDS file into a R object. Uses [readRDS()].}
+#' }
 #' 
 #' @section rio's import() and JSON files:
 #' In rio (0.5.18) there was a change in how JSON files are processed by
@@ -37,11 +38,11 @@
 #' In keeping with the spirit of `jsonlite`, `box_read_json()` has been
 #' modified to call `jsonlite::fromJSON()` directly, which by-passes the old
 #' "undesirable" behavior of `rio` (< 0.5.18). If you are using the current CRAN
-#' release of `rio` (0.5.16) you should use `box_read_json()` to avoid these issues.
+#' release of `rio` (0.5.16) you should use [jsonlite::read_json()] to avoid these issues.
 #' 
 #' @inheritParams box_dl
 #' @param type `character`, 
-#'   [MIME type](http://en.wikipedia.org/wiki/Internet_media_type)  
+#'   [MIME type](https://en.wikipedia.org/wiki/Internet_media_type)  
 #'   used to override the content type returned by the server. 
 #' @param read_fun `function`, used to read (parse) the content into R; for `box_read()`
 #'   the default function is [rio::import()]; the specific helpers
@@ -149,3 +150,10 @@ box_read_json <- function(file_id, ...) {
 box_read_excel <- function(file_id, ...) {
   box_read(file_id, format = "excel", ...)
 }
+
+#' @rdname box_read
+#' @export
+box_read_rds <- function(file_id, ...) {
+  box_read(file_id, read_fun = readRDS, ...)
+}
+
